==> v4.3.3.tar.gz: omegat-4.3.3/src/org/omegat/core/spellchecker/SpellCheckerLangToolHunspell.java <==
/**************************************************************************
 OmegaT - Computer Assisted Translation (CAT) tool
          with fuzzy matching, translation memory, keyword search,
          glossaries, and translation leveraging into updated projects.

 Copyright (C) 2016 Aaron Madlon-Kay
               Home page: http://www.omegat.org/
               Support center: http://groups.yahoo.com/group/OmegaT/

 This file is part of OmegaT.

 OmegaT is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 OmegaT is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/

package org.omegat.core.spellchecker;

import java.io.UnsupportedEncodingException;
import java.nio.charset.CharacterCodingException;
import java.util.Collections;
import java.util.List;

import org.languagetool.rules.spelling.hunspell.Hunspell;
import org.omegat.util.Log;

/**
 * A thin wrapper around the LanguageTool Hunspell implementation (which itself
 * wraps native libs)
 *
 * @author Aaron Madlon-Kay
 */
public class SpellCheckerLangToolHunspell implements ISpellCheckerProvider {

    private final String dictBasename;
    private final Hunspell.Dictionary dict;

    public SpellCheckerLangToolHunspell(String dictBasename) throws Throwable {
        this.dictBasename = dictBasename;
        this.dict = Hunspell.getInstance().getDictionary(dictBasename);
    }

    @Override
    public boolean isCorrect(String word) {
        return !dict.misspelled(word);
    }

    @Override
    public List<String> suggest(String word) {
        try {
            return dict.suggest(word);
        } catch (CharacterCodingException e) {
            return Collections.emptyList();
        }
    }

    @Override
    public void learnWord(String word) {
        try {
            dict.addWord(word);
        } catch (UnsupportedEncodingException e) {
            Log.log(e);
        }
    }

    @Override
    public void destroy() {
        dict.destroy();
        Hunspell.getInstance().destroyDictionary(dictBasename);
    }
}

==> v5.7.1.tar.gz: omegat-5.7.1/src/org/omegat/core/spellchecker/SpellCheckerLangToolHunspell.java <==
/**************************************************************************
 OmegaT - Computer Assisted Translation (CAT) tool
          with fuzzy matching, translation memory, keyword search,
          glossaries, and translation leveraging into updated projects.

 Copyright (C) 2016 Aaron Madlon-Kay
               Home page: http://www.omegat.org/
               Support center: https://omegat.org/support

 This file is part of OmegaT.

 OmegaT is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 OmegaT is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/

package org.omegat.core.spellchecker;

import java.io.UnsupportedEncodingException;
import java.nio.charset.CharacterCodingException;
import java.util.Collections;
import java.util.List;

import org.languagetool.rules.spelling.hunspell.Hunspell;
import org.omegat.util.Log;

/**
 * A thin wrapper around the LanguageTool Hunspell implementation (which itself
 * wraps native libs)
 *
 * @author Aaron Madlon-Kay
 */
public class SpellCheckerLangToolHunspell implements ISpellCheckerProvider {

    private final String dictBasename;
    private final Hunspell.Dictionary dict;

    public SpellCheckerLangToolHunspell(String dictBasename) throws Throwable {
        this.dictBasename = dictBasename;
        this.dict = Hunspell.getInstance().getDictionary(dictBasename);
    }

    @Override
    public boolean isCorrect(String word) {
        return !dict.misspelled(word);
    }

    @Override
    public List<String> suggest(String word) {
        try {
            return dict.suggest(word);
        } catch (CharacterCodingException e) {
            return Collections.emptyList();
        }
    }

    @Override
    public void learnWord(String word) {
        try {
            dict.addWord(word);
        } catch (UnsupportedEncodingException e) {
            Log.log(e);
        }
    }

    @Override
    public void destroy() {
        dict.destroy();
        Hunspell.getInstance().destroyDictionary(dictBasename);
    }
}
